==> devops-client-0.2.4-sources.jar: io/alauda/devops/client/dsl/internal/ImageStreamTagOperationsImpl.java <==
/**
 * Copyright (C) 2018 Alauda
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.alauda.devops.client.dsl.internal;

import java.util.Map;
import java.util.TreeMap;

import io.alauda.kubernetes.client.dsl.Resource;
import io.fabric8.openshift.api.model.DoneableImageStreamTag;
import io.fabric8.openshift.api.model.ImageStreamTag;
import io.fabric8.openshift.api.model.ImageStreamTagList;
import io.alauda.devops.client.AlaudaDevOpsConfig;
import okhttp3.OkHttpClient;

import static io.alauda.devops.client.AlaudaAPIGroups.IMAGE;

public class ImageStreamTagOperationsImpl extends AlaudaOperation<ImageStreamTag, ImageStreamTagList, DoneableImageStreamTag,
  Resource<ImageStreamTag, DoneableImageStreamTag>> {

  public ImageStreamTagOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String namespace) {
    this(client, config, null, namespace, null, true, null, null, false, -1, new TreeMap<String, String>(), new TreeMap<String, String>(), new TreeMap<String, String[]>(), new TreeMap<String, String[]>(), new TreeMap<String, String>());
  }

  public ImageStreamTagOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String apiVersion, String namespace, String name, Boolean cascading, ImageStreamTag item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, AlaudaOperation.withApiGroup(client, IMAGE, apiVersion, config), "imagestreamtags", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }
}

==> devops-client-0.2.4.3-sources.jar: io/alauda/devops/client/dsl/internal/ImageStreamTagOperationsImpl.java <==
/**
 * Copyright (C) 2018 Alauda
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.alauda.devops.client.dsl.internal;

import java.util.Map;
import java.util.TreeMap;

import io.alauda.kubernetes.client.dsl.Resource;
import io.alauda.devops.api.model.DoneableImageStreamTag;
import io.alauda.devops.api.model.ImageStreamTag;
import io.alauda.devops.api.model.ImageStreamTagList;
import io.alauda.devops.client.AlaudaDevOpsConfig;
import okhttp3.OkHttpClient;

import static io.alauda.devops.client.AlaudaAPIGroups.IMAGE;

public class ImageStreamTagOperationsImpl extends AlaudaOperation<ImageStreamTag, ImageStreamTagList, DoneableImageStreamTag,
  Resource<ImageStreamTag, DoneableImageStreamTag>> {

  public ImageStreamTagOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String namespace) {
    this(client, config, null, namespace, null, true, null, null, false, -1, new TreeMap<String, String>(), new TreeMap<String, String>(), new TreeMap<String, String[]>(), new TreeMap<String, String[]>(), new TreeMap<String, String>());
  }

  public ImageStreamTagOperationsImpl(OkHttpClient client, AlaudaDevOpsConfig config, String apiVersion, String namespace, String name, Boolean cascading, ImageStreamTag item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, AlaudaOperation.withApiGroup(client, IMAGE, apiVersion, config), "imagestreamtags", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }
}
